# poly-match
使用rust为python提速100倍!

## 简介
本项目是对[poly-match](https://github.com/ohadravid/poly-match)项目的重构, 通过该项目你可以熟悉如何使用rust编写python推展,并熟悉rye的基本使用方法.

## 安装
本项目已经发布到pypi, 可以通过pip安装
```bash
pip install poly-match
```

## 使用
```python
poly-match benchmark
```

